==> release-1.6.1.tar.gz: dsbdirect/app/src/main/java/godau/fynn/dsbdirect/HtmlTable.java <==
/*
 * DSBDirect
 * Copyright (C) 2019 Fynn Godau
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * This software is not affiliated with heinekingmedia GmbH, the
 * developer of the DSB platform.
 */

package godau.fynn.dsbdirect;

import android.util.Log;
import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;

public class HtmlTable extends Table {

    public HtmlTable(String uri, String publishedTime) {
        super(uri, publishedTime, true);
    }



    public static String cleanupHtmlForParsing(String html) {
        html = html.replaceAll("<td class=\"\\w+\" align=\"\\w+\">(\\d+\\w+, ?)+(\\d+\\w+,? ?)*(Q\\d+,? ?)*<\\/td>", ""); // we don't need "Betroffene Klassen" contents // I am proud of my RegEx // it could probably be improved
        html = html.replaceAll("<br>", " "); // <br> tags confuse Reader
        return html.replaceAll("<strike.*>.+</strike>", "---"); // strike tags also confuse Reader
    }

    public static String cleanupHtmlForRendering(String html) {
        html = html.replaceAll("Untis Stundenplan Software", "");
        html = html.replaceAll("<strong>Untis</strong> 20\\d\\d", "");
        //html = html.replaceAll("font: 80% Arial, Helvetica, sans-serif;", "");
        html = html.replaceAll("Alexander-von-Humboldt-Gymnasium", "");
        html = html.replaceAll("D-97424 Schweinfurt", "");
        html = html.replaceAll("Stundenplan 20\\d\\d/\\d\\d", "");
        return html.replaceAll("Stand: \\d\\d.\\d\\d.\\d\\d\\d\\d \\d\\d:\\d\\d", "");
    }
}

==> release-1.8.1.tar.gz: dsbdirect/app/src/main/java/godau/fynn/dsbdirect/HtmlTable.java <==
/*
 * DSBDirect
 * Copyright (C) 2019 Fynn Godau
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * This software is not affiliated with heinekingmedia GmbH, the
 * developer of the DSB platform.
 */

package godau.fynn.dsbdirect;

import android.net.Uri;

import java.util.Date;

public class HtmlTable extends Table {

    public HtmlTable(String uri, Date publishedTime) {
        super(uri, publishedTime, true);
    }



    public static String cleanupHtmlForParsing(String html) {
        html = html.replaceAll("<td class=\"\\w+\" align=\"\\w+\">(\\d+\\w+, ?)+(\\d+\\w+,? ?)*(Q\\d+,? ?)*<\\/td>", ""); // we don't need "Betroffene Klassen" contents // I am proud of my RegEx // it could probably be improved
        html = html.replaceAll("<br>", " "); // <br> tags confuse Reader
        return html.replaceAll("<strike.*>.+</strike>", "---"); // strike tags also confuse Reader
    }

    public static String cleanupHtmlForRendering(String html) {
        html = html.replaceAll("Untis Stundenplan Software", "");
        html = html.replaceAll("<strong>Untis</strong> 20\\d\\d", "");
        //html = html.replaceAll("font: 80% Arial, Helvetica, sans-serif;", "");
        html = html.replaceAll("Alexander-von-Humboldt-Gymnasium", "");
        html = html.replaceAll("D-97424 Schweinfurt", "");
        html = html.replaceAll("Stundenplan 20\\d\\d/\\d\\d", "");
        return html.replaceAll("Stand: \\d\\d.\\d\\d.\\d\\d\\d\\d \\d\\d:\\d\\d", "");
    }
}
